@@ -36,7 +36,7 @@
 #include "eog-config-keys.h"
 
 #include <glib/gi18n.h>
-#include <glib/gkeyfile.h>
+#include <glib.h>
 #include <libgnome/gnome-util.h>
 #include <gconf/gconf-client.h>
 
@@ -303,7 +303,7 @@ eog_plugin_engine_load_dir (const gchar *dir)
 	d = g_dir_open (dir, 0, &error);
 
 	if (!d)	{
-		g_warning (error->message);
+		g_warning ("%s", error->message);
 		g_error_free (error);
 
 		return;
@@ -365,7 +365,7 @@ eog_plugin_engine_load_all (void)
 	g_free (pdir);
 
 	/* Load system plugins */
-	eog_plugin_engine_load_dir (EOG_PLUGINDIR "/");
+	eog_plugin_engine_load_dir (EOG_PLUGIN_DIR "/");
 }
 
 gboolean
